package
Version:
v0.0.0-...-87de96b
Opens a new window with list of versions in this module.
Published: Sep 16, 2020
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
VERSION represents the platform version
func GetMajorVersion() int
TODO: GetMajorVersion
func GetMicroVersion() int
TODO: GetMicroVersion
func GetMinorVersion() int
TODO: GetMinorVersion
Source Files
¶
Directories
¶
|
|
|
server
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Click to show internal directories.
Click to hide internal directories.